@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # Copyright (C) 2021 maxence business consulting GmbH, http://www.maxence.de
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -931,6 +931,7 @@ sub _ShowEdit {
     $LayoutObject->Block( Name => 'ActionOverview' );
 
     if ( $Param{Action} eq 'Change' ) {
+
         $LayoutObject->Block(
             Name => 'ActionClone',
             Data => \%Param,
@@ -943,10 +944,14 @@ sub _ShowEdit {
             Name => 'ActionHistory',
             Data => \%Param,
         );
-        $LayoutObject->Block(
-            Name => 'ActionDelete',
-            Data => \%Param,
-        );
+
+        # Show ‘Delete’ button only for invalid web services
+        if ( $WebserviceData->{ValidID} ne '1' ) {
+            $LayoutObject->Block(
+                Name => 'ActionDelete',
+                Data => \%Param,
+            );
+        }
         $LayoutObject->Block(
             Name => 'ActionDebugger',
             Data => \%Param,
