@@ -139,6 +139,7 @@ sub Run {
             if ($Content) {
                 $MainObject->Require('Text::Diff');
                 my $Diff = Text::Diff::diff( \$File, $Content, { STYLE => 'OldStyle' } );
+                $Kernel::OM->Get('Kernel::System::Encode')->EncodeInput( \$Diff );
                 $LayoutObject->Block(
                     Name => "FileDiff",
                     Data => {
@@ -1946,6 +1947,7 @@ sub _InstallHandling {
         $Data{PackageRequired} = $PackageObject->GetRequiredPackages(
             Structure => \%Structure,
         );
+        $Data{PackageRequiredProblem} = grep { $_->{IsInstalled} eq 0 } @{ $Data{PackageRequired} };
     }
 
     # parse sopm-file and show <ModuleRequired> information
@@ -1953,6 +1955,7 @@ sub _InstallHandling {
         $Data{ModuleRequired} = $PackageObject->GetRequiredModules(
             Structure => \%Structure,
         );
+        $Data{ModuleRequiredProblem} = grep { $_->{IsInstalled} eq 0 } @{ $Data{ModuleRequired} };
     }
 
     my %Response = $PackageObject->AnalyzePackageFrameworkRequirements(
