@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -895,6 +895,23 @@ sub _ShowEdit {
         Class       => 'Modernize',
     );
 
+    if ( $LayoutObject->{BrowserRichText} ) {
+
+        $Param{RichTextCSS} = 'RichText';
+
+        # set up rich text editor
+        $LayoutObject->SetRichTextParameters(
+            Data => \%Param,
+        );
+    }
+
+    $LayoutObject->Block(
+        Name => 'ArticleContainer',
+        Data => {
+            %Param
+        },
+    );
+
     my @ChannelList = $Kernel::OM->Get('Kernel::System::CommunicationChannel')->ChannelList();
 
     # Allow only Internal and Phone communication channels, this has to be hard coded at the moment.
