@@ -11,6 +11,7 @@ package Kernel::Modules::AgentTicketMerge;
 
 use strict;
 use warnings;
+use utf8;
 
 use Kernel::System::VariableCheck qw(:all);
 use Kernel::Language qw(Translatable);
@@ -389,36 +390,25 @@ sub Run {
     else {
         my $ArticleObject = $Kernel::OM->Get('Kernel::System::Ticket::Article');
 
-        # Get last customer article.
-        my @Articles = $ArticleObject->ArticleList(
-            TicketID   => $Self->{TicketID},
-            SenderType => 'customer',
-            OnlyLast   => 1,
-        );
+        my %Article;
 
-        # If the ticket has no customer article, get the last agent article.
-        if ( !@Articles ) {
-            @Articles = $ArticleObject->ArticleList(
+        # Preferentially get the last customer article.
+        # If there are none, get the last one of an agent
+        # Last resort is without SenderType
+        SENDERTYPE:
+        for my $SenderType ( qw( customer agent ), undef ) {
+            my @Articles = $ArticleObject->ArticleList(
                 TicketID   => $Self->{TicketID},
-                SenderType => 'agent',
+                SenderType => $SenderType,
                 OnlyLast   => 1,
             );
-        }
+            next SENDERTYPE if !@Articles;
 
-        # Finally, if everything failed, get latest article.
-        if ( !@Articles ) {
-            @Articles = $ArticleObject->ArticleList(
-                TicketID => $Self->{TicketID},
-                OnlyLast => 1,
-            );
-        }
-
-        my %Article;
-        for my $Article (@Articles) {
-            %Article = $ArticleObject->BackendForArticle( %{$Article} )->ArticleGet(
-                %{$Article},
+            %Article = $ArticleObject->BackendForArticle( %{ $Articles[0] } )->ArticleGet(
+                %{ $Articles[0] },
                 DynamicFields => 1,
             );
+            last SENDERTYPE;
         }
 
         # merge box
@@ -428,13 +418,23 @@ sub Run {
             BodyClass => 'Popup',
         );
 
+        # We need a minimal Recipient salutation templating
+        my %Recipient;
+        my $RecipientName = $Article{From};
+        if ($RecipientName) {
+            my ($ParsedAddress) = Mail::Address->parse($RecipientName);
+            $Recipient{Realname} = $ParsedAddress->phrase() if $ParsedAddress;
+        }
+
         # prepare salutation
         my $TemplateGenerator = $Kernel::OM->Get('Kernel::System::TemplateGenerator');
         my $Salutation        = $TemplateGenerator->Salutation(
-            TicketID  => $Self->{TicketID},
-            ArticleID => $Article{ArticleID},
-            Data      => {%Article},
-            UserID    => $Self->{UserID},
+            TicketID   => $Self->{TicketID},
+            ArticleID  => $Article{ArticleID},
+            Data       => {%Article},
+            TicketData => \%Ticket,
+            UserID     => $Self->{UserID},
+            Recipient  => \%Recipient,
         );
 
         # prepare signature
