@@ -105,13 +105,22 @@ sub Run {
         );
     }
 
-    if ( $Param{UserData}->{UserID} eq $Self->{UserID} ) {
+    # Update session data when the preference is updated by the user himself.
+    if ( $Param{UpdateSessionData} ) {
         $SessionObject->UpdateSessionID(
             SessionID => $Self->{SessionID},
             Key       => $Self->{ConfigItem}->{PrefKey},
             Value     => $LastViewTypes,
         );
     }
+    else {
+
+        # Delete the session when the preference is updated by an admin user
+        # to force a login with fresh session data for the affected user.
+        $SessionObject->RemoveSessionByUser(
+            UserLogin => $Param{UserData}->{UserLogin},
+        );
+    }
 
     $Self->{Message} = Translatable('Preferences updated successfully!');
     return 1;
