@@ -52,14 +52,10 @@ sub Run {
         UserID => $Self->{UserID},
     ) // [];
 
-    my $MentionsCount;
     my $NewMentionsCount;
+    my $MentionsCount;
 
     if ( IsArrayRefWithData($Mentions) ) {
-
-        # set mention count of all mentions
-        $MentionsCount = @{$Mentions};
-
         my @MentionedTicketIDs = map { $_->{TicketID} } @{$Mentions};
 
         # get mention count of unseen mentions
@@ -72,10 +68,16 @@ sub Run {
                 MentionSeen => 0,
             }
         );
+
+        # get mention count of all mentions
+        $MentionsCount = $TicketObject->TicketSearch(
+            Result   => 'COUNT',
+            TicketID => \@MentionedTicketIDs,
+            UserID   => $Self->{UserID},
+        );
     }
 
     my $MentionsConfig = $ConfigObject->Get('Mentions') // {};
-
     if ( $MentionsConfig->{ToolbarCount} ) {
         $AdditionalParams{Mentions}->{Count}    = $MentionsCount;
         $AdditionalParams{NewMentions}->{Count} = $NewMentionsCount;
@@ -91,17 +93,6 @@ sub Run {
         = $AdditionalParams{NewMentions}->{Count} ? Translatable('Total new mentions') : Translatable('New mentions');
 
     my %Return;
-    if ($MentionsCount) {
-        $Return{ $Priority++ } = {
-            %{ $AdditionalParams{Mentions} },
-            Block       => 'ToolBarItem',
-            Description => $MentionLabel,
-            Class       => $Param{Config}->{CssClass},
-            Icon        => $Icon,
-            Link        => $URL . 'Action=AgentTicketMentionView',
-            AccessKey   => $Param{Config}->{AccessKey} || '',
-        };
-    }
     if ($NewMentionsCount) {
         $Return{ $Priority++ } = {
             %{ $AdditionalParams{NewMentions} },
@@ -113,6 +104,17 @@ sub Run {
             AccessKey   => $Param{Config}->{AccessKey} || '',
         };
     }
+    if ($MentionsCount) {
+        $Return{ $Priority++ } = {
+            %{ $AdditionalParams{Mentions} },
+            Block       => 'ToolBarItem',
+            Description => $MentionLabel,
+            Class       => $Param{Config}->{CssClass},
+            Icon        => $Icon,
+            Link        => $URL . 'Action=AgentTicketMentionView',
+            AccessKey   => $Param{Config}->{AccessKey} || '',
+        };
+    }
 
     return %Return;
 }
