@@ -1137,7 +1137,7 @@ generate SQL condition query based on a search expression
         Key          => 'some_col',
         Value        => '(ABC+DEF)',
         SearchPrefix => '',
-        SearchSuffix => '*'
+        SearchSuffix => '*',
         Extended     => 1, # use also " " as "&&", e.g. "bob smith" -> "bob&&smith"
     );
 
@@ -1166,7 +1166,7 @@ generate SQL condition query based on a search expression
     return the SQL String with ?-values and a array with values references:
 
     $BindModeResult = (
-        'SQL'    => 'WHERE testa LIKE ? AND testb NOT LIKE ? AND testc = ?'
+        'SQL'    => 'WHERE testa LIKE ? AND testb NOT LIKE ? AND testc = ?',
         'Values' => ['a', 'b', 'c'],
     )
 
