@@ -862,40 +862,27 @@ sub QueueAdd {
         Type => $Self->{CacheType},
     );
 
-    my $StandardTemplate2QueueByCreating = $ConfigObject->Get('StandardTemplate2QueueByCreating');
-
     # add default responses (if needed), add response by name
-    if (
-        $StandardTemplate2QueueByCreating
-        && ref $StandardTemplate2QueueByCreating eq 'ARRAY'
-        && @{$StandardTemplate2QueueByCreating}
-        )
-    {
+    my $StandardTemplateObject           = $Kernel::OM->Get('Kernel::System::StandardTemplate');
+    my $StandardTemplate2QueueByCreating = $ConfigObject->Get('StandardTemplate2QueueByCreating') // [];
 
-        # get standard template object
-        my $StandardTemplateObject = $Kernel::OM->Get('Kernel::System::StandardTemplate');
+    ST:
+    for my $ST ( @{$StandardTemplate2QueueByCreating} ) {
 
-        ST:
-        for my $ST ( @{$StandardTemplate2QueueByCreating} ) {
+        my $StandardTemplateID = $StandardTemplateObject->StandardTemplateLookup(
+            StandardTemplate => $ST,
+        );
 
-            my $StandardTemplateID = $StandardTemplateObject->StandardTemplateLookup(
-                StandardTemplate => $ST,
-            );
+        next ST if !$StandardTemplateID;
 
-            next ST if !$StandardTemplateID;
-
-            $Self->QueueStandardTemplateMemberAdd(
-                QueueID            => $QueueID,
-                StandardTemplateID => $StandardTemplateID,
-                Active             => 1,
-                UserID             => $Param{UserID},
-            );
-        }
+        $Self->QueueStandardTemplateMemberAdd(
+            QueueID            => $QueueID,
+            StandardTemplateID => $StandardTemplateID,
+            Active             => 1,
+            UserID             => $Param{UserID},
+        );
     }
 
-    # get standard template id
-    my $StandardTemplateID2QueueByCreating = $ConfigObject->Get(' StandardTemplate2QueueByCreating');
-
     # get queue data with updated name for QueueCreate event
     my %Queue = $Self->QueueGet( Name => $Param{Name} );
 
@@ -908,21 +895,6 @@ sub QueueAdd {
         UserID => $Param{UserID},
     );
 
-    return $QueueID if !$StandardTemplateID2QueueByCreating;
-    return $QueueID if ref $StandardTemplateID2QueueByCreating ne 'ARRAY';
-    return $QueueID if !@{$StandardTemplateID2QueueByCreating};
-
-    # add template by id
-    for my $StandardTemplateID ( @{$StandardTemplateID2QueueByCreating} ) {
-
-        $Self->QueueStandardTemplateMemberAdd(
-            QueueID            => $QueueID,
-            StandardTemplateID => $StandardTemplateID,
-            Active             => 1,
-            UserID             => $Param{UserID},
-        );
-    }
-
     return $QueueID;
 }
 
@@ -1197,6 +1169,11 @@ sub QueueUpdate {
         ],
     );
 
+    # reset cache
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
+
     # get queue data with updated name for QueueUpdate event
     my %Queue = $Self->QueueGet( Name => $Param{Name} );
 
@@ -1210,11 +1187,6 @@ sub QueueUpdate {
         UserID => $Param{UserID},
     );
 
-    # reset cache
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => $Self->{CacheType},
-    );
-
     # updated all sub queue names
     my @ParentQueue = split( /::/, $OldQueue{Name} );
 
