@@ -191,10 +191,8 @@ sub SLAGet {
     # check if result is already cached
     my $CacheKey = 'Cache::SLAGet::' . $Param{SLAID};
     my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-        Type           => $Self->{CacheType},
-        Key            => $CacheKey,
-        CacheInMemory  => 1,
-        CacheInBackend => 0,
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
     );
 
     if ( ref $Cached eq 'HASH' ) {
@@ -295,9 +293,7 @@ sub SLAGet {
         Key  => $CacheKey,
 
         # make a local copy of the sla data to avoid it being altered in-memory later
-        Value          => {%SLAData},
-        CacheInMemory  => 1,
-        CacheInBackend => 0,
+        Value => {%SLAData},
     );
 
     return %SLAData;
@@ -339,10 +335,8 @@ sub SLALookup {
         # check cache
         my $CacheKey = 'Cache::SLALookup::ID::' . $Param{SLAID};
         my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-            Type           => $Self->{CacheType},
-            Key            => $CacheKey,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
+            Type => $Self->{CacheType},
+            Key  => $CacheKey,
         );
         if ( defined $Cached ) {
             return $Cached;
@@ -363,12 +357,10 @@ sub SLALookup {
 
         # cache
         $Kernel::OM->Get('Kernel::System::Cache')->Set(
-            Type           => $Self->{CacheType},
-            TTL            => $Self->{CacheTTL},
-            Key            => $CacheKey,
-            Value          => $Name,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
+            Type  => $Self->{CacheType},
+            TTL   => $Self->{CacheTTL},
+            Key   => $CacheKey,
+            Value => $Name,
         );
 
         return $Name;
@@ -378,10 +370,8 @@ sub SLALookup {
         # check cache
         my $CacheKey = 'Cache::SLALookup::Name::' . $Param{Name};
         my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-            Type           => $Self->{CacheType},
-            Key            => $CacheKey,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
+            Type => $Self->{CacheType},
+            Key  => $CacheKey,
         );
         if ( defined $Cached ) {
             return $Cached;
@@ -402,12 +392,10 @@ sub SLALookup {
 
         # cache
         $Kernel::OM->Get('Kernel::System::Cache')->Set(
-            Type           => $Self->{CacheType},
-            TTL            => $Self->{CacheTTL},
-            Key            => $CacheKey,
-            Value          => $SLAID,
-            CacheInMemory  => 1,
-            CacheInBackend => 0,
+            Type  => $Self->{CacheType},
+            TTL   => $Self->{CacheTTL},
+            Key   => $CacheKey,
+            Value => $SLAID,
         );
 
         return $SLAID;
