@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -1639,10 +1639,10 @@ sub _TicketAttributes {
         Number       => Translatable('Number'),               # only a counter for a better readability
         TicketNumber => $ConfigObject->Get('Ticket::Hook'),
 
-        #TicketID       => 'TicketID',
-        Age   => 'Age',
-        Title => 'Title',
-        Queue => 'Queue',
+        TicketID => 'TicketID',
+        Age      => 'Age',
+        Title    => 'Title',
+        Queue    => 'Queue',
 
         #QueueID        => 'QueueID',
         State => 'State',
@@ -1750,6 +1750,7 @@ sub _SortedAttributes {
     my @SortedAttributes = qw(
         Number
         TicketNumber
+        TicketID
         Age
         Title
         Created
