@@ -79,10 +79,12 @@ Please run it as the 'otrs' user or with the help of su:
 ";
     }
 
-    $Kernel::OM->Create('scripts::Migration')->Run(
+    my $Result = $Kernel::OM->Create('scripts::Migration')->Run(
         CommandlineOptions => \%Options,
     );
 
+    exit 1 if !$Result;
+
     exit 0;
 }
 
