@@ -128,12 +128,16 @@ sub _GetMigrateSysConfigSettings {
             UpdateEffectiveValue => {
                 'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js' => 'thirdparty/jquery-jstree-3.3.8/jquery.jstree.js',
                 'thirdparty/nunjucks-3.2.2/nunjucks.min.js'       => 'thirdparty/nunjucks-3.2.3/nunjucks.min.js',
+                'thirdparty/jquery-validate-1.16.0/jquery.validate.js' =>
+                    'thirdparty/jquery-validation-1.21.0/jquery.validate.js',
             },
         },
         "Loader::Customer::CommonJS###000-Framework" => {
             UpdateEffectiveValue => {
                 'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js' => 'thirdparty/jquery-jstree-3.3.8/jquery.jstree.js',
                 'thirdparty/nunjucks-3.2.2/nunjucks.min.js'       => 'thirdparty/nunjucks-3.2.3/nunjucks.min.js',
+                'thirdparty/jquery-validate-1.16.0/jquery.validate.js' =>
+                    'thirdparty/jquery-validation-1.21.0/jquery.validate.js',
             },
         },
     );
